Top

    TempleConcordance
    Providence, Rhode Island
    February 1st 2008
    2R+F
    12 players
    Matt Morgan

    Deck Name: Howling Anarchs
    Description: Continuing in my quest to with a tournament with
    every clan alphabetically, I had to put together an Ahrimanes
    deck.  I hadn't ever played them much and generally felt like
    they were a decent clan, but Howler always goes to torpor, so
    that's a pretty major liability.  I asked for some advice on
    the #vtes irc chat and eventually jhattara gave me the idea of
    playing your traditional blocking felines with some Anarch Revolts
    to speed the table up.  Great idea!  Still not having much experience
    with Ahrmanes, I basically copied David Quinonero's famous deck
    and shoehorned some Anarch Revolts.  It turned out pretty well,
    if a little slow.  I won my first round by the skin of my teeth
    and had to settle for a 2-2 split in the 2nd as my prey sort of
    ran away with the table.  The deck was ideal for the more
    deliberately-played final and I won with 2.5VP.

    Crypt (12 cards, min=12, max=32, avg=5.75)
    ------------------------------------------
    4x Howler	    8	ANI PRE SPI obf		Ahrimane:2
    2x Siamese, The	    7	PRE SPI ani pro		Ahrimane:2
    1x Cynthia Ingold   6	SPI ani for pre		Ahrimane:2
    1x Nettie Hale	    5	ani cel pre pro spi	Ahrimane:2
    1x Bobby Lemon	    4	ANI pro			Gangrel:3
    1x Juanita Santiago 4	ani pre spi		Ahrimane:2
    1x Dani		    2	ani			Nosferatu antitribu:2
    1x Gillian Krader   2	ani dem			Pander:2

    /* I decided to throw a couple small guys in, but in general
    they weren't super helpful.  The deck is basically Howler
    with maybe The Siamese or Cynthia filling in if Howler is
    unwilling or unable to perform her duties. */

    Library (90)
    Master [19]
    1x Anarch Free Press, The
    /* Not free and doesn't provide a press.  Can we get some
    errata?  The one time I tried to play this it was Suddened. */
    4x Anarch Revolt
    1x Animalism
    2x Direct Intervention
    1x Fame
    1x Giant's Blood
    1x Guardian Angel
    1x Rack, The
    1x Seattle Committee
    1x Smiling Jack, The Anarch
    5x Vessel

    /* The Anarch Revolts and Fame were responsible for both my
    game wins.  I think I nailed a couple Blood Dolls with Vessels,
    but I mostly included them over Blood Dolls because I was
    worried about master hand jam. */

    Action [11]
    1x Aranthebes, The Immortal
    6x Enchant Kindred
    4x Nose of the Hound

    /* Didn't need Aranthebes because of a lack of weenie predators.
    I mostly played the Enchant Kindreds at inferior, so they might've
    been better bleed cards (Legal, Social, Entrancement?).  4x Nose
    of the Hound was pretty nice. */

    Combat/Action Modifier [5]
    5x Swiftness of the Stag

    /* Okay, so I actually got my firsts ousts in the games I
    won by bleeding for 2 at 1 stealth, but I like to think the
    Anarch Revolts and Fame are what got me there.  These were
    pretty good for keeping things up close and personal with
    Flash Harrison. */

    Equipment [1]
    1x Flak Jacket

    /* Never when I needed it.  Sigh.  Same with the Guardian Angel. */

    Event [1]
    1x Dragonbound

    /* This was mostly only good for backousting Jesse when he
    wouldn't let Howler out of a Pentex. */

    Reaction [22]
    4x Cats' Guidance
    4x Falcon's Eye
    3x On the Qui Vive
    3x Sense the Savage Way
    8x Speak with Spirits

    /* I nearly lost the first game because I just couldn't draw
    any untap or intercept and my prey was getting away with murder
    for it.  It's weird because this looks like plenty to me. */

    Retainer [11]
    6x Murder of Crows
    1x Owl Companion
    4x Raven Spy

    /* The Murders are pretty good here in that they make up for
    the fact that the support crew have inferior Animalism (not
    too scary on its own) and let Howler save on blood by doing
    a good amount of damage from long range. */

    Combat [20]
    5x Aid from Bats
    2x Canine Horde
    3x Carrion Crows
    8x Pack Alpha
    2x Taste of Vitae

    /* Pretty light combat package, especially since 8 of those
    cards don't actually do anything to hurt the opponent or
    protect my minion.  The deck obviously relies heavily on
    Howler's natural abilities and whatever permanents it can
    put together.  Some Leapfrog or Majesty or something might've
    been good, but I didn't feel like there was room for it
    and it was more important to be able to hurt opposing minions. */